summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmditaskbar.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmditaskbar.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
index c333070a..2de377cb 100644
--- a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
+++ b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
@@ -6,8 +6,8 @@
// begin : 07/1999 by Szymon Stefanek as part of kvirc
// (an IRC application)
// changes : 09/1999 by Falk Brettschneider to create an
-// - 06/2000 stand-alone Qt extension set of
-// classes and a Qt-based library
+// - 06/2000 stand-alone TQt extension set of
+// classes and a TQt-based library
// 2000-2003 maintained by the KDevelop project
//
// copyright : (C) 1999-2003 by Falk Brettschneider
@@ -48,9 +48,10 @@ class KMdiTaskBarButtonPrivate;
* It's a special kind of TQPushButton catching mouse clicks.
* And you have the ability to abbreviate the text that it fits in the button.
*/
-class KMdiTaskBarButton : public QPushButton
+class KMdiTaskBarButton : public TQPushButton
{
Q_OBJECT
+ TQ_OBJECT
// methods
public:
/**
@@ -87,7 +88,7 @@ signals:
*/
void rightMouseButtonClicked( KMdiChildView* );
/**
* Emitted when the button text has changed. Internally connected with KMdiTaskBar::layoutTaskBar
*/
void buttonTextChanged( int );
public slots:
@@ -129,11 +130,12 @@ class KMdiTaskBarPrivate;
class KMDI_EXPORT KMdiTaskBar : public KToolBar
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor (NoFocus, minimum width = 1, an internal TQPtrList of taskbar buttons (autodelete))
*/
- KMdiTaskBar( KMdiMainFrm *parent, TQMainWindow::ToolBarDock dock );
+ KMdiTaskBar( KMdiMainFrm *tqparent, TQMainWindow::ToolBarDock dock );
/**
* Destructor (deletes the taskbar button list)
*/
@@ -171,7 +173,7 @@ public:
};
protected:
/**
* Reimplemented from its base class to call layoutTaskBar, additionally.
*/
void resizeEvent( TQResizeEvent* );
protected slots:
@@ -182,7 +184,7 @@ protected slots:
* fixed width and show() is called for each one.
* If one drags the taskbar to a vertical orientation, the button width is set to 80 pixel.
*/
- void layoutTaskBar( int taskBarWidth = 0 );
+ void tqlayoutTaskBar( int taskBarWidth = 0 );
public slots:
/**
* Pushes the desired taskbar button down (switch on), the old one is released (switched off).
@@ -196,7 +198,7 @@ protected:
*/
TQPtrList<KMdiTaskBarButton>* m_pButtonList;
/**
* The belonging MDI mainframe (parent widget of this)
*/
KMdiMainFrm* m_pFrm;
/**
@@ -215,5 +217,5 @@ private:
};
#endif //_KMDITASKBAR_H_
-// kate: space-indent off; tab-width 4; replace-tabs off; indent-mode csands;
+// kate: space-indent off; tab-width 4; tqreplace-tabs off; indent-mode csands;
@@ -87,7 +88,7 @@ signals:
void rightMouseButtonClicked( KMdiChildView* );
/**
- * Emitted when the button text has changed. Internally connected with KMdiTaskBar::layoutTaskBar
+ * Emitted when the button text has changed. Internally connected with KMdiTaskBar::tqlayoutTaskBar
*/
void buttonTextChanged( int );
@@ -171,7 +173,7 @@ public:
protected:
/**
- * Reimplemented from its base class to call layoutTaskBar, additionally.
+ * Reimplemented from its base class to call tqlayoutTaskBar, additionally.
*/
void resizeEvent( TQResizeEvent* );
@@ -196,7 +198,7 @@ protected:
TQPtrList<KMdiTaskBarButton>* m_pButtonList;
/**
- * The belonging MDI mainframe (parent widget of this)
+ * The belonging MDI mainframe (tqparent widget of this)
*/
KMdiMainFrm* m_pFrm;